#! @bin_dir@/pybliographer -q

# This file is part of pybliographer
# 
# Copyright (C) 1998 Frederic GOBRY
# Email : gobry@idiap.ch
# 	   
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2 
# of the License, or (at your option) any later version.
#   
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details. 
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# 
# $Id: pybliographic.py,v 1.5 2000/03/23 14:31:25 fredgo Exp $

import sys

from gtk import *
from Pyblio.GnomeUI.Pybliographic import Pybliographic
from Pyblio.Fields import URL

main = Pybliographic ()

if len (sys.argv) > 2:
    for file in sys.argv [2:]:
        url = URL (file)
        
        main.open_document (str (url))
else:
    main.new_document ()

mainloop ()

